# esrlabs-auto-update

esrlabs-auto-update is a service which tracks ESR Labs tools and install updates.

## Install

First time you need to run the `install.py` script and specify the installation path.
Script will create the `esrlabs-tools` directory and will install all tools there.
```
python install.py --install-dir ~/.
```
